Interned

Struct Interned 

pub struct Interned<T>(pub &'static T)
where
    T: Internable + 'static + ?Sized;
An interned value. Will stay valid until the end of the program and will not drop.

For details on interning, see the module level docs.

Comparisons

Interned values use reference equality, meaning they implement Eq and Hash regardless of whether T implements these traits. Two interned values are only guaranteed to compare equal if they were interned using the same Interner instance.

#[derive(PartialEq, Eq, Hash, Debug)]
struct Value(i32);
impl Internable for Value {
    // ...
}
let interner_1 = Interner::new();
let interner_2 = Interner::new();
// Even though both values are identical, their interned forms do not
// compare equal as they use different interner instances.
assert_ne!(interner_1.intern(&Value(42)), interner_2.intern(&Value(42)));

Tuple Fields

0: &'static T