Trait Internable
pub trait Internable: Hash + Eq {
// Required methods
fn leak(&self) -> &'static Self;
fn ref_eq(&self, other: &Self) -> bool;
fn ref_hash<H>(&self, state: &mut H)
where H: Hasher;
}Expand description
A trait for internable values.
This is used by Interner<T> to create static references for values that are interned.
Required Methods
fn leak(&self) -> &'static Self
fn leak(&self) -> &'static Self
Creates a static reference to self, possibly leaking memory.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.