Struct Interned
pub struct Interned<T>(pub &'static T)
where
T: Internable + 'static + ?Sized;Expand description
An interned value. Will stay valid until the end of the program and will not drop.
For details on interning, see the module level docs.
Comparisons
Interned values use reference equality, meaning they implement Eq
and Hash regardless of whether T implements these traits.
Two interned values are only guaranteed to compare equal if they were interned using
the same Interner instance.
#[derive(PartialEq, Eq, Hash, Debug)]
struct Value(i32);
impl Internable for Value {
// ...
}
let interner_1 = Interner::new();
let interner_2 = Interner::new();
// Even though both values are identical, their interned forms do not
// compare equal as they use different interner instances.
assert_ne!(interner_1.intern(&Value(42)), interner_2.intern(&Value(42)));Tuple Fields
0: &'static TTrait Implementations
impl<T> Clone for Interned<T>where
T: Internable + ?Sized,
impl<T> Clone for Interned<T>where
T: Internable + ?Sized,
impl<T> Deref for Interned<T>where
T: Internable + ?Sized,
impl<T> Deref for Interned<T>where
T: Internable + ?Sized,
impl<T> FromReflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> FromReflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
fn from_reflect(reflect: &(dyn PartialReflect + 'static)) -> Option<Interned<T>>
fn from_reflect(reflect: &(dyn PartialReflect + 'static)) -> Option<Interned<T>>
Constructs a concrete instance of
Self from a reflected value.fn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreimpl<T> GetTypeRegistration for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> GetTypeRegistration for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
fn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
Returns the default [
TypeRegistration] for this type.fn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers other types needed by this type. Read more
impl<T> Hash for Interned<T>where
T: Internable + ?Sized,
impl<T> Hash for Interned<T>where
T: Internable + ?Sized,
impl<T> PartialEq for Interned<T>where
T: Internable + ?Sized,
impl<T> PartialEq for Interned<T>where
T: Internable + ?Sized,
impl<T> PartialReflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> PartialReflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Returns the [
TypeInfo] of the type represented by this value. Read morefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Returns a zero-sized enumeration of “kinds” of type. Read more
fn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an immutable enumeration of “kinds” of type. Read more
fn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
fn reflect_owned(self: Box<Interned<T>>) -> ReflectOwned
fn reflect_owned(self: Box<Interned<T>>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
fn try_into_reflect(
self: Box<Interned<T>>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<Interned<T>>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Attempts to cast this type to a boxed, fully-reflected value.
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
Attempts to cast this type to a fully-reflected value.
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
Attempts to cast this type to a mutable, fully-reflected value.
fn into_partial_reflect(self: Box<Interned<T>>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<Interned<T>>) -> Box<dyn PartialReflect>
Casts this type to a boxed, reflected value. Read more
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
Casts this type to a reflected value. Read more
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
Casts this type to a mutable, reflected value. Read more
fn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
fn reflect_partial_eq(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Returns a “partial equality” comparison result. Read more
fn reflect_partial_cmp(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<Ordering>
fn reflect_partial_cmp( &self, value: &(dyn PartialReflect + 'static), ) -> Option<Ordering>
Returns a “partial comparison” result. Read more
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Attempts to clone
Self using reflection. Read morefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Applies a reflected value to this value. Read more
fn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>where
T: 'static,
Self: Sized + TypePath,
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>where
T: 'static,
Self: Sized + TypePath,
For a type implementing [
PartialReflect], combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
[ReflectCloneError] if the downcast fails.fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
fn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
impl<T> Reflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> Reflect for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
Returns the value as a
&mut dyn Any. Read morefn into_reflect(self: Box<Interned<T>>) -> Box<dyn Reflect>
fn into_reflect(self: Box<Interned<T>>) -> Box<dyn Reflect>
Casts this type to a boxed, fully-reflected value.
fn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Casts this type to a fully-reflected value.
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Casts this type to a mutable, fully-reflected value.
impl Schedulable for Interned<dyn SystemSet>
impl Schedulable for Interned<dyn SystemSet>
type Metadata = GraphInfo
type Metadata = GraphInfo
Additional data used to configure independent scheduling. Stored in
ScheduleConfig.type GroupMetadata = Chain
type GroupMetadata = Chain
Additional data used to configure a schedulable group. Stored in
ScheduleConfigs.fn into_config(self) -> ScheduleConfig<Interned<dyn SystemSet>>
fn into_config(self) -> ScheduleConfig<Interned<dyn SystemSet>>
Initializes a configuration from this node.
impl ScheduleLabel for Interned<dyn ScheduleLabel>
impl ScheduleLabel for Interned<dyn ScheduleLabel>
fn dyn_clone(&self) -> Box<dyn ScheduleLabel>
fn dyn_clone(&self) -> Box<dyn ScheduleLabel>
Clones this
ScheduleLabel.fn intern(&self) -> Interned<dyn ScheduleLabel>
fn intern(&self) -> Interned<dyn ScheduleLabel>
Returns an
Interned value corresponding to self.impl SystemSet for Interned<dyn SystemSet>
impl SystemSet for Interned<dyn SystemSet>
fn system_type(&self) -> Option<TypeId>
fn system_type(&self) -> Option<TypeId>
Returns
Some if this system set is a SystemTypeSet.fn is_anonymous(&self) -> bool
fn is_anonymous(&self) -> bool
Returns
true if this system set is an AnonymousSet.impl<T> TupleStruct for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> TupleStruct for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
fn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
fn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field with index
index as a
&dyn Reflect.fn field_mut(
&mut self,
index: usize,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_mut( &mut self, index: usize, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field with index
index
as a &mut dyn Reflect.fn iter_fields(&self) -> TupleStructFieldIter<'_>
fn iter_fields(&self) -> TupleStructFieldIter<'_>
Returns an iterator over the values of the tuple struct’s fields.
fn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
fn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
Creates a new [
DynamicTupleStruct] from this tuple struct.fn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
fn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
Will return
None if [TypeInfo] is not available.impl<T> TypePath for Interned<T>
impl<T> TypePath for Interned<T>
fn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
fn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
impl<T> Typed for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> Typed for Interned<T>where
T: Internable + 'static + TypePath + ?Sized,
Interned<T>: Any + Send + Sync,
&'static T: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl<T> Copy for Interned<T>where
T: Internable + ?Sized,
impl<T> Eq for Interned<T>where
T: Internable + ?Sized,